from  distutils.core import setup
setup(
    name = 'testInstall',
    version = '1.1.0',
    py_modules = ['testInstall'],
    author = 'fanxinglanyu',
    author_mail = 'jinkang22@foxmail.com',
    description = '测试安装库'
)